# Import local modules
from photoshop.api.colors.cmyk import CMYKColor
from photoshop.api.colors.gray import GrayColor
from photoshop.api.colors.hsb import HSBColor
from photoshop.api.colors.lab import LabColor
from photoshop.api.colors.rgb import RGBColor


__all__ = [
    CMYKColor.__name__,
    GrayColor.__name__,
    HSBColor.__name__,
    LabColor.__name__,
    RGBColor.__name__,
]
